@@ -4,7 +4,7 @@
 
 
 # Only allow bash
-if [ -z "${BASH_SOURCE}" ]; then
+if [[ -z "${BASH_SOURCE}" ]]; then
     echo "Don't be ridiculous. Use bash." >&2
     return 1
 fi
@@ -32,6 +32,7 @@ deactivate () {
     # Cleanup temporary files
     shopt -s nullglob
     rm -f tmp/{pre,post}_activate_*.$$
+    shopt -u nullglob
 
     # Fix PWD and OLDPWD
     cd - > /dev/null; OLDPWD="${__OLDPWD}"; unset __OLDPWD
@@ -45,7 +46,7 @@ deactivate () {
 __OLDPWD="${OLDPWD}"; cd "$(dirname "${BASH_SOURCE}")/.."
 
 # Create a temporary directory
-if [ ! -d tmp ]; then
+if [[ ! -d tmp ]]; then
     mkdir tmp
 else
     # Clean up temporary files for processes that no longer exist
@@ -55,32 +56,39 @@ else
             rm -f $i
         fi
     done
+    shopt -u nullglob
 fi
 
-# Save a list of current environment variables
-env | awk -F"=" '{print $1}' | sort > tmp/pre_activate_variables.$$
-# Save a list of current aliases
-alias | awk '{print $2}' | awk -F"=" '{print $1}' | sort > tmp/pre_activate_aliases.$$
-# Save a list of current functions
-declare -F | awk '{print $NF}' | sort > tmp/pre_activate_functions.$$
+if [[ -z "${VIRTUALENV_ACTIVATOR_SIMPLE}" ]]; then
+    # Save a list of current environment variables
+    env | awk -F"=" '{print $1}' | sort > tmp/pre_activate_variables.$$
+    # Save a list of current aliases
+    alias | awk '{print $2}' | awk -F"=" '{print $1}' | sort > tmp/pre_activate_aliases.$$
+    # Save a list of current functions
+    declare -F | awk '{print $NF}' | sort > tmp/pre_activate_functions.$$
 
-# Save the entire shell environment minus certain variables that we don't want to mess with
-set | grep -v "^BASH" \
-    | grep -v "^\(__OLDPWD\)=" \
-    | grep -v "^\(PWD\|OLDPWD\|EUID\|UID\|PPID\|SHELLOPTS\)=" \
-    > tmp/pre_activate_environment.$$
+    # Save the entire shell environment minus certain variables that we don't want to mess with
+    set | grep -v "^BASH" \
+        | grep -v "^\(__OLDPWD\)=" \
+        | grep -v "^\(PWD\|OLDPWD\|EUID\|UID\|PPID\|SHELLOPTS\)=" \
+        > tmp/pre_activate_environment.$$
+else
+    # These things don't make sense for simple mode
+    export VIRTUAL_ENV_DISABLE_PROMPT=1
+    unset -f deactivate
+fi
 
 # These are the two most important variables in your virtual environment
 export VIRTUAL_ENV="$(pwd)"
 export PATH="${VIRTUAL_ENV}/bin:${PATH}"
 
 # Unset PYTHONHOME if set
-if [ -n "${PYTHONHOME}" ]; then
+if [[ -n "${PYTHONHOME}" ]]; then
     unset PYTHONHOME
 fi
 
 # Change the shell prompt unless explicitly disabled
-if [ -z "${VIRTUAL_ENV_DISABLE_PROMPT}" ]; then
+if [[ -z "${VIRTUAL_ENV_DISABLE_PROMPT}" ]]; then
     # If the directory name is generic, use the parent directory name
     if [[ $(basename "${VIRTUAL_ENV}") =~ ^\.?v(irtual)?env$ ]]; then
         export PS1="($(basename "$(dirname "${VIRTUAL_ENV}")")) ${PS1}"
@@ -97,7 +105,7 @@ alias pydoc="python -m pydoc"
 function pip () { python -m pip "$@"; virtualenv --relocatable "${VIRTUAL_ENV}" > /dev/null 2>&1; }
 
 # Include any extra stuff in the environment
-if [ -f etc/environment.sh ]; then
+if [[ -f etc/environment.sh ]]; then
     source etc/environment.sh
 fi
 
